# -*- coding: utf-8 -*-

#    Copyright 2018 Youssef El Ouahby <youssef@yaltik.com>
#    Copyright 2018 Fabien Bourgeois <fabien@yaltik.com>
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU Affero General Public License as
#    published by the Free Software Foundation, either version 3 of the
#    License, or (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU Affero General Public License for more details.
#
#    You should have received a copy of the GNU Affero General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.

""" GOLEM Activity adaptations """

from odoo import models, fields, api

class GolemActivity(models.Model):
    """ GOLEM Activity adaptations """
    _inherit = 'golem.activity'

    @api.multi
    def get_mass_mailing_action(self, action_type):
        """ Call activity mass mailing presend wizard """
        presend_wizard = self.env['golem.mail.presend.wizard'].create({})
        if action_type == 'animators':
            partners = self.mapped('animator_id').ids
            for partner in partners:
                self.env['golem.mail.recipient'].create({'partner_id': partner,
                                                         'presend_wizard_id': presend_wizard.id})
            act_name = 'Activity animators mass mailing'
        elif action_type == 'members':
            partner_ids = self.mapped('activity_registration_ids').mapped(
                'member_id').mapped('partner_id').ids
            for partner in partner_ids:
                self.env['golem.mail.recipient'].create({'partner_id': partner,
                                                         'presend_wizard_id': presend_wizard.id})
            act_name = 'Activity members mass mailing'
        return {
            'type': 'ir.actions.act_window',
            'name': act_name,
            'res_model': 'golem.mail.presend.wizard',
            'res_id': presend_wizard.id,
            'view_mode': 'form',
            'view_type': 'form',
            'target': 'new'
            }
